Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(207)

Unified Diff: chrome/browser/sync/test/integration/profile_sync_service_harness.h

Issue 2551023006: [Sync] SyncEngine 1.5: Fix all backend references in PSS. (Closed)
Patch Set: Fix Android. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/profile_sync_service_harness.h
diff --git a/chrome/browser/sync/test/integration/profile_sync_service_harness.h b/chrome/browser/sync/test/integration/profile_sync_service_harness.h
index 20de77dc987e1dbfa8398acdb4d9bfaa617456a8..b4b82eb24c0a4f98daa69dad2a1b7ed36558a8a8 100644
--- a/chrome/browser/sync/test/integration/profile_sync_service_harness.h
+++ b/chrome/browser/sync/test/integration/profile_sync_service_harness.h
@@ -82,11 +82,11 @@ class ProfileSyncServiceHarness {
static bool AwaitQuiescence(
const std::vector<ProfileSyncServiceHarness*>& clients);
- // Blocks the caller until the sync backend is initialized or some end state
- // (e.g., auth error) is reached. Returns true if and only if the backend
- // initialized successfully. See ProfileSyncService's IsBackendInitialized()
- // method for the definition of backend initialization.
- bool AwaitBackendInitialization();
+ // Blocks the caller until the sync engine is initialized or some end state
+ // (e.g., auth error) is reached. Returns true if and only if the engine
+ // initialized successfully. See ProfileSyncService's IsEngineInitialized()
+ // method for the definition of engine initialization.
+ bool AwaitEngineInitialization();
// Blocks the caller until sync setup is complete. Returns true if and only
// if sync setup completed successfully. See syncer::SyncService's

Powered by Google App Engine
This is Rietveld 408576698